aboutsummaryrefslogtreecommitdiff
path: root/google/ads/googleads/v2/resources/landing_page_view.proto
diff options
context:
space:
mode:
Diffstat (limited to 'google/ads/googleads/v2/resources/landing_page_view.proto')
-rw-r--r--google/ads/googleads/v2/resources/landing_page_view.proto4
1 files changed, 2 insertions, 2 deletions
diff --git a/google/ads/googleads/v2/resources/landing_page_view.proto b/google/ads/googleads/v2/resources/landing_page_view.proto
index c4c08be03..59117a823 100644
--- a/google/ads/googleads/v2/resources/landing_page_view.proto
+++ b/google/ads/googleads/v2/resources/landing_page_view.proto
@@ -40,12 +40,12 @@ message LandingPageView {
pattern: "customers/{customer}/landingPageViews/{landing_page_view}"
};
// Immutable. The resource name of the landing page view.
// Landing page view resource names have the form:
//
// `customers/{customer_id}/landingPageViews/{unexpanded_final_url_fingerprint}`
string resource_name = 1 [
- (google.api.field_behavior) = IMMUTABLE,
+ (google.api.field_behavior) = OUTPUT_ONLY,
(google.api.resource_reference) = {
type: "googleads.googleapis.com/LandingPageView"
}
@@ -40,12 +40,12 @@ message LandingPageView {
pattern: "customers/{customer}/landingPageViews/{landing_page_view}"
};
- // Immutable. The resource name of the landing page view.
+ // Output only. The resource name of the landing page view.
// Landing page view resource names have the form:
//